@@ -25,13 +25,34 @@ Dectalk voice parameter settings.
 
 """
 
-__id__ = "$Id: dectalk.py 3957 2008-06-04 16:43:04Z richb $"
+__id__ = "$Id$"
 __author__ = "T. V. Raman"
-__version__ = "$Revision: 3957 $"
-__date__ = "$Date: 2008-06-04 12:43:04 -0400 (Wed, 04 Jun 2008) $"
+__version__ = "$Revision$"
+__date__ = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Google Inc."
 __license__ = "LGPL"
 
+import chnames
+
+# Handling of special characters
+#
+# Emacspeak uses Tcl syntax to communicate with its speech servers.  It
+# embraces text in curly braces, so that at least {, }, and \ must be quoted
+# when sending text to speech server.  But individual speech engines have
+# their own special characters in addition to those of Tcl.  Dectalk
+# perceives speech parameters enclosed in square brackets, and Emacspeak
+# exploits this to transmit speech settings to Dectalk.  Thus we must quote
+# [ and ] too.
+
+def makeSpecialCharMap():
+    """Returns list of pairs mapping characters which are special for
+    Dectalk speech server to their replacements.
+    """
+    chars = r'{\}[]'
+    return [(ch, ' '+chnames.getCharacterName(ch)+' ') for ch in chars]
+
+
+# Speech parameters
 
 _defined_voices = {}
 
