@@ -805,7 +805,7 @@ class Script(default.Script):
             # it's not selected.
             #
             text = event.any_data
-            if text.isupper():
+            if text.decode("UTF-8").isupper():
                 speech.speak(text, self.voices[settings.UPPERCASE_VOICE])
             else:
                 speech.speak(text)
