@@ -899,7 +899,8 @@ doubleClickTimeout = 0.5
 #
 def isAccessibilityEnabled():
     try:
-        return gconfClient.get_bool("/desktop/gnome/interface/accessibility")
+        return gconfClient.get_bool("/desktop/gnome/interface/accessibility") \
+            or gconfClient.get_bool("/desktop/gnome/interface/accessibility2")
     except:
         return False
 
@@ -1081,6 +1082,8 @@ setScriptMapping(re.compile(_('Minefield')), "Mozilla")
 #setScriptMapping(re.compile(_('Shiretoko')), "Mozilla")
 setScriptMapping(re.compile('Shiretoko'), "Mozilla")
 
+setScriptMapping(re.compile('Namoroka'), "Mozilla")
+
 # This is a temporary fix for the schema/FF 3.0 not being accessible
 # issue. (See GNOME bugs #535827 and #555466.)
 #
@@ -1115,7 +1118,6 @@ setScriptMapping(re.compile(_('vte')), "gnome-terminal")
 # supporting gaim, which has recently be renamed to pidgin.
 #
 setScriptMapping(re.compile(_('gaim')), "pidgin")
-setScriptMapping(re.compile('Pidgin'), "pidgin")
 
 # Translators: see the regular expression note above.  This is for
 # supporting yelp, which sometimes identifies itself as gnome-help.
